Welcome to Django Stuff's documentation!
============================================

Django Stuff is a collection of tools and utilities to make your development with Django simpler.

Features
--------

- TimeStamp and History models to giving you information like when your record wore created/updated and History Changes
- UUID Model as primary key or not instead of sequence ID.
- Serializer model to return a dict with all data of your django instance.
- Signals model to add any task before or after you save, update or delete your model
- And many other stuff. For more information, see our documentation following the links below.
- Backend to Login using email or username

Quickstart
----------

.. toctree::
    :maxdepth: 2

    quickstart/installation.rst


User Guide
----------

.. toctree::
    :maxdepth: 2

    backends/index.rst
    fields.rst
    forms.rst
    models/index.rst
    utils.rst


Development
-----------

.. toctree::
    :maxdepth: 1

    development/installation.rst
    development/release.rst


Downloads
---------

- `PDF <https://readthedocs.org/projects/django-api-client/downloads/pdf/latest/>`_

- `Epub <https://readthedocs.org/projects/django-api-client/downloads/epub/latest/>`_


Other
-----

.. toctree::

    changelog.rst
